innerchemlmer: innerchemlmer

innerchemlmerR Documentation

innerchemlmer

Description

Running one regression model for chemical data

Usage

innerchemlmer(
  data,
  outcome,
  id,
  weights,
  value = "value",
  confound = NULL,
  type = "filter",
  resid = F
)

Arguments

data

dataset

outcome

character outcome variable (string format)

id

ID variable

value

column name for value (string format)

confound

character vector of confound variable (default is null)

type

Whether to return only chemical effect (default is filter)

resid

whether to output residuals

weight

weight variable

Details

innerchemlmer Run linear mixed effects model with weights for chemical data

This is a function to run a single regression model for chemical data

Examples

data(simchemdatmixed)
# limit to one chemical
dat1 <- dplyr::filter(simchemdatmixed, chem == "chem1")
res <- innerchemlmer(dat1, outcome = "out", id = "id", weights = "weights")

kralljr/chemregr documentation built on Nov. 28, 2022, 3:01 p.m.