| innerchemlmer | R Documentation |
Running one regression model for chemical data
innerchemlmer( data, outcome, id, weights, value = "value", confound = NULL, type = "filter", resid = F )
data |
dataset |
outcome |
character outcome variable (string format) |
id |
ID variable |
value |
column name for value (string format) |
confound |
character vector of confound variable (default is null) |
type |
Whether to return only chemical effect (default is filter) |
resid |
whether to output residuals |
weight |
weight variable |
innerchemlmer Run linear mixed effects model with weights for chemical data
This is a function to run a single regression model for chemical data
data(simchemdatmixed) # limit to one chemical dat1 <- dplyr::filter(simchemdatmixed, chem == "chem1") res <- innerchemlmer(dat1, outcome = "out", id = "id", weights = "weights")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.